#! /usr/bin/env bash
# This script records a complete sequence of commands to reproduce this
# package build in the CodeSourcery environment.  It includes commands
# requiring proprietary sources not included in the source package
# and the actual directory names used in the build.  Running this
# script outside the CodeSourcery environment is not supported, but
# it serves to provide documentation of how the open source components
# of this package have been configured.
set -e
inform_fd=2 

check_status() {
    local status="$?"
    if [ "$status" -ne 0 ]; then
	return "$status"
    fi
}

check_pipe() {
    local -a status=("${PIPESTATUS[@]}")
    local limit=$1
    local ix
    
    if [ -z "$limit" ] ; then
	limit="${#status[@]}"
    fi
    for ((ix=0; ix != $limit ; ix++)); do
	if [ "${status[$ix]}" != "0" ] ; then
	    return "${status[$ix]}"
	fi
    done
}

error () {
    echo "$script: error: $@" >& $inform_fd
    exit 1
}

warning () {
    echo "$script: warning: $@" >& $inform_fd
}

copy_dir() {
    mkdir -p "$2"
    # Use tar, rather than cp -r, so that symlinks are preserved.
    (cd "$1" && tar cf - .) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_clean() {
    mkdir -p "$2"
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	.) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_exclude() {
    local source="$1"
    local dest="$2"
    local excl="$3"
    shift 3
    mkdir -p "$dest"
    (cd "$source" && tar cfX - "$excl" "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

copy_dir_only() {
    local source="$1"
    local dest="$2"
    shift 2
    mkdir -p "$dest"
    (cd "$source" && tar cf - "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

clean_environment() {
    local env_var_list
    local var

    # Unset variables taken by bash from the environment in
    # noninteractive shells and affecting bash itself in undesirable
    # ways.  Other variables need only be unexported.
    unset BASH_ENV CDPATH POSIXLY_CORRECT TMOUT

    env_var_list=$(export | \
	grep '^declare -x ' | \
	sed -e 's/^declare -x //' -e 's/=.*//')

    for var in $env_var_list; do
	case $var in
	    CSL_SCRIPTDIR|HOME|LOGNAME|PWD|SHELL|SSH_*|TERM|USER)
		# These variables are OK to export and may be required
		# by this process or subprocesses.
		;;
	    LD_LIBRARY_PATH|PATH|XML_CATALOG_FILES)
		# PATH and LD_LIBRARY_PATH are set separately after
		# the release config has been read; see setup_path.
		;;
	    *)
		# On Cygwin, there are environment variables that cannot be unset, like "!C".
		export -n "$var" || true
		;;
	esac
    done

    # Use the C locale.
    export LANG=C
    export LC_ALL=C

    # Used for local CVS checkouts.
    export CVS_RSH=ssh

    # Ensure the shell running this script is also used for other
    # purposes.
    export SHELL=$BASH
    export CONFIG_SHELL=$BASH
}

pushenv() {
    pushenv_level=$(($pushenv_level + 1))
    eval pushenv_vars_${pushenv_level}=
}


pushenv_level=0
pushenv_vars_0=



pushenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    eval local pushenv_oldset=\"\${$pushenv_var+set}\"
    local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
    local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
    eval local pushenv_save_set=\"\${$pushenv_savep_var+set}\"
    if [ "$pushenv_save_set" = "set" ]; then
	error "Pushing $pushenv_var more than once at level $pushenv_level"
    fi
    if [ "$pushenv_oldset" = "set" ]; then
	eval $pushenv_save_var=\"\$pushenv_oldval\"
    else
	unset $pushenv_save_var
    fi
    eval $pushenv_savep_var=1
    eval export $pushenv_var=\"\$pushenv_newval\"
    local pushenv_list_var=pushenv_vars_${pushenv_level}
    eval $pushenv_list_var=\"\$$pushenv_list_var \$pushenv_var\"
}

prependenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    pushenvvar "$pushenv_var" "$pushenv_newval$pushenv_oldval"
}

popenv() {
    local pushenv_var=
    eval local pushenv_vars=\"\$pushenv_vars_${pushenv_level}\"
    for pushenv_var in $pushenv_vars; do
	local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
	local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
	eval local pushenv_save_val=\"\$$pushenv_save_var\"
	eval local pushenv_save_set=\"\${$pushenv_save_var+set}\"
	unset $pushenv_save_var
	unset $pushenv_savep_var
	if [ "$pushenv_save_set" = "set" ]; then
	    eval export $pushenv_var=\"\$pushenv_save_val\"
	else
	    unset $pushenv_var
	fi
    done
    unset pushenv_vars_${pushenv_level}
    if [ "$pushenv_level" = "0" ]; then
	error "Popping environment level 0"
    else
	pushenv_level=$(($pushenv_level - 1))
    fi
}

prepend_path() {
    if $(eval "test -n \"\$$1\""); then
	prependenvvar "$1" "$2:"
    else
	prependenvvar "$1" "$2"
    fi
}
pushenvvar CSL_SCRIPTDIR /scratch/paul/arm/scripts
pushenvvar PATH /usr/local/tools/gcc-3.4.0/bin:/bin:/usr/bin
pushenvvar LD_LIBRARY_PATH /usr/local/tools/gcc-3.4.0/lib64:/usr/local/tools/gcc-3.4.0/lib
pushenvvar XML_CATALOG_FILES ''
clean_environment
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/arm/obj
mkdir -p /scratch/paul/arm/install
mkdir -p /scratch/paul/arm/pkg
mkdir -p /scratch/paul/arm/logs
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf.src.tar.bz2 /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf.backup.tar.bz2
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/binutils-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/binutils-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' binutils-2.17
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/gcc-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/gcc-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gcc-2006q3
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/expat-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/expat-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' expat-mirror
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/make-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/make-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' make-3.81
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/coreutils-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/coreutils-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' coreutils-5.94
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/csl_docbook-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/csl_docbook-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-docbook-trunk
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/getting_started-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/getting_started-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' getting-started-stable
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/libiconv-2006q3-26.tar.bz2
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
pushd /scratch/paul/arm/src
tar cf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf/libiconv-2006q3-26.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' libiconv-1.11
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/src/getting-started-stable/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --with-release-config=4.1-arm-none-symbianelf '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/arm/src/csl-docbook-trunk --with-version-string=2006q3-26 '--with-brand=ARM Sourcery G++ Lite' --with-editions=lite --with-options-dtd=default.dtd '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/paul/arm/install htmldir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/man docdir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/src/expat-mirror/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/paul/arm/obj/host-libs-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/paul/arm/src/binutils-2.17 /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery '--with-pkgversion=CodeSourcery ARM Sourcery G++ 2006q3-26' --with-bugurl=mailto:arm-gnu@codesourcery.com --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/paul/arm/install htmldir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/install
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f lib/charset.alias
popd
copy_dir_clean /scratch/paul/arm/src/binutils-2.17/include /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
chmod -R u+w /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
mkdir -p /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/libiberty/libiberty.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/bfd/.libs/libbfd.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/bfd/bfd.h /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/paul/arm/src/binutils-2.17/bfd/elf-bfd.h /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/opcodes/.libs/libopcodes.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
rm -rf /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/gcc
cat > /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/gcc/as <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/arm/install/arm-none-symbianelf/bin/as "$@"
EOF0
chmod +x /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/gcc/as
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/gcc
cat > /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/gcc/collect-ld <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/arm/install/arm-none-symbianelf/bin/ld "$@"
EOF0
chmod +x /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/gcc/collect-ld
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/arm/src/gcc-2006q3/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery --enable-languages=c,c++ '--with-versuffix=CodeSourcery ARM Sourcery G++ 2006q3-26' '--with-pkgversion=CodeSourcery ARM Sourcery G++ 2006q3-26' --with-bugurl=mailto:arm-gnu@codesourcery.com --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu
make prefix=/scratch/paul/arm/install htmldir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/share/doc/arm-2006q3-26-arm-none-symbianelf/man install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushenv
pushd /scratch/paul/arm/install
rm -f lib/libiberty.a
rm -f bin/arm-none-symbianelf-gccbug
rm -f lib/charset.alias
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushd /scratch/paul/arm/install
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f lib/charset.alias
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
find /scratch/paul/arm/install -name '*.la' -exec rm '{}' ';'
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
pushd /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.1.1/include
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-addr2line
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-ar
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-as
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-c++
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-c++filt
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-cpp
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-g++
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gcc
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gcc-4.1.1
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gcov
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-gprof
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-ld
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-nm
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-objcopy
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-objdump
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-ranlib
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-readelf
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-size
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-strings
/usr/bin/strip /scratch/paul/arm/install/bin/arm-none-symbianelf-strip
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/ar
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/as
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/c++
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/g++
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/gcc
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/ld
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/nm
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/objdump
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/ranlib
/usr/bin/strip /scratch/paul/arm/install/arm-none-symbianelf/bin/strip
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.1.1/cc1
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.1.1/collect2
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.1.1/install-tools/fixincl
/usr/bin/strip /scratch/paul/arm/install/libexec/gcc/arm-none-symbianelf/4.1.1/cc1plus
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/arm-none-symbianelf/lib/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/arm-none-symbianelf/lib/softfp/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.1.1/libgcov.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.1.1/libgcc.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.1.1/softfp/libgcov.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/arm/install/lib/gcc/arm-none-symbianelf/4.1.1/softfp/libgcc.a || true
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
rm -f /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2
pushd /scratch/paul/arm/obj
rm -f arm-2006q3
ln -s /scratch/paul/arm/install arm-2006q3
tar cjf /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --owner=0 --group=0 arm-2006q3/arm-none-symbianelf arm-2006q3/bin arm-2006q3/include arm-2006q3/lib arm-2006q3/libexec arm-2006q3/share
rm -f arm-2006q3
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
/scratch/paul/arm/scripts/gnu-rpm-inst -h i686-pc-linux-gnu -p /scratch/paul/arm/pkg -o /scratch/paul/arm/obj 4.1-arm-none-symbianelf.cfg
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/arm/install/bin
/scratch/paul/arm/scripts/gnu-installanywhere -p /scratch/paul/arm/pkg -h i686-pc-linux-gnu -f /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu/license.html 4.1-arm-none-symbianelf.cfg
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32
ln -s . arm-2006q3
tar xf /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
rm arm-2006q3
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/getting-started-stable/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --with-release-config=4.1-arm-none-symbianelf '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/arm/src/csl-docbook-trunk --with-version-string=2006q3-26 '--with-brand=ARM Sourcery G++ Lite' --with-editions=lite --with-options-dtd=default.dtd '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/man docdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/expat-mirror/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/scratch/paul/arm/obj/host-libs-2006q3-26-arm-none-symbianelf-i686-mingw32/usr --disable-shared --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/libiconv-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/libiconv-2006q3-26-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/libiconv-2006q3-26-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/libiconv-1.11/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/scratch/paul/arm/obj/host-libs-2006q3-26-arm-none-symbianelf-i686-mingw32/usr --disable-shared --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/libiconv-2006q3-26-arm-none-symbianelf-i686-mingw32
make -j1
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/libiconv-2006q3-26-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/make-src-2006q3-26-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/arm/src/make-3.81 /scratch/paul/arm/obj/make-src-2006q3-26-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/arm/obj/make-src-2006q3-26-arm-none-symbianelf-i686-mingw32
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/make-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/make-2006q3-26-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/make-2006q3-26-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/obj/make-src-2006q3-26-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/make-2006q3-26-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/make-2006q3-26-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/coreutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/arm/src/coreutils-5.94 /scratch/paul/arm/obj/coreutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/arm/obj/coreutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/coreutils-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/coreutils-2006q3-26-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/coreutils-2006q3-26-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/obj/coreutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/coreutils-2006q3-26-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/coreutils-2006q3-26-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/arm/src/binutils-2.17 /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery '--with-pkgversion=CodeSourcery ARM Sourcery G++ 2006q3-26' --with-bugurl=mailto:arm-gnu@codesourcery.com --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f lib/charset.alias
popd
copy_dir_clean /scratch/paul/arm/src/binutils-2.17/include /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/include
chmod -R u+w /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/include
mkdir -p /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/libiberty/libiberty.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/bfd/.libs/libbfd.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/bfd/bfd.h /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/paul/arm/src/binutils-2.17/bfd/elf-bfd.h /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/opcodes/.libs/libopcodes.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-i686-mingw32/usr/lib
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32/gcc
cat > /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32/gcc/as <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin/as "$@"
EOF0
chmod +x /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32/gcc/as
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32/gcc
cat > /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32/gcc/collect-ld <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin/ld "$@"
EOF0
chmod +x /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32/gcc/collect-ld
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32
/scratch/paul/arm/src/gcc-2006q3/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery --enable-languages=c,c++ '--with-versuffix=CodeSourcery ARM Sourcery G++ 2006q3-26' '--with-pkgversion=CodeSourcery ARM Sourcery G++ 2006q3-26' --with-bugurl=mailto:arm-gnu@codesourcery.com --disable-nls --with-libiconv-prefix=/scratch/paul/arm/obj/host-libs-2006q3-26-arm-none-symbianelf-i686-mingw32/usr
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32
make -j4 all-gcc
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-i686-mingw32
make prefix=/scratch/paul/arm/install/host-i686-mingw32 htmldir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-i686-mingw32/share/doc/arm-2006q3-26-arm-none-symbianelf/man install-gcc
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/arm/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f bin/arm-none-symbianelf-gccbug
rm -f lib/charset.alias
popd
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/lib/gcc/arm-none-symbianelf /scratch/paul/arm/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/lib /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/lib
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/include/c++ /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/include/c++
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/paul/arm/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f lib/charset.alias
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
find /scratch/paul/arm/install/host-i686-mingw32 -name '*.la' -exec rm '{}' ';'
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/paul/arm/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf/4.1.1/include
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-addr2line.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-ar.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-as.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-c++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-c++filt.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-cpp.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-g++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc-4.1.1
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gcov.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-gprof.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-ld.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-nm.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-objcopy.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-objdump.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-ranlib.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-readelf.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-size.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-strings.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/arm-none-symbianelf-strip.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/make.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/bin/rm.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/ar.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/as.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/c++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/g++.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/gcc.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/ld.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/nm.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/objdump.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/ranlib.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/arm-none-symbianelf/bin/strip.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.1.1/cc1.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.1.1/collect2.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.1.1/install-tools/fixincl.exe
i686-mingw32-strip /scratch/paul/arm/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.1.1/cc1plus.exe
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
rm -f /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-i686-mingw32.tar.bz2
pushd /scratch/paul/arm/obj
rm -f arm-2006q3
ln -s /scratch/paul/arm/install/host-i686-mingw32 arm-2006q3
tar cjf /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-i686-mingw32.tar.bz2 --owner=0 --group=0 -h arm-2006q3/arm-none-symbianelf arm-2006q3/bin arm-2006q3/include arm-2006q3/lib arm-2006q3/libexec arm-2006q3/share
rm -f arm-2006q3
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-i686-mingw32/bin
/scratch/paul/arm/scripts/gnu-installanywhere -p /scratch/paul/arm/pkg -h i686-mingw32 -f /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-i686-mingw32/license.html 4.1-arm-none-symbianelf.cfg
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
rm -rf /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
pushd /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
ln -s . arm-2006q3
tar xf /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
rm arm-2006q3
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
rm -rf /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
/scratch/paul/arm/src/getting-started-stable/configure --build=i686-pc-linux-gnu --host=sparc-sun-solaris2.8 --target=arm-none-symbianelf --prefix=/opt/codesourcery --with-release-config=4.1-arm-none-symbianelf '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/arm/src/csl-docbook-trunk --with-version-string=2006q3-26 '--with-brand=ARM Sourcery G++ Lite' --with-editions=lite --with-options-dtd=default.dtd '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/getting_started-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make install prefix=/scratch/paul/arm/install/host-sparc-sun-solaris2.8 htmldir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/man docdir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
rm -rf /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
/scratch/paul/arm/src/expat-mirror/configure --build=i686-pc-linux-gnu --host=sparc-sun-solaris2.8 --target=arm-none-symbianelf --prefix=/scratch/paul/arm/obj/host-libs-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr --disable-shared --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/expat-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make install
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
copy_dir_clean /scratch/paul/arm/src/binutils-2.17 /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
chmod -R u+w /scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
rm -rf /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
/scratch/paul/arm/obj/binutils-src-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/configure --build=i686-pc-linux-gnu --host=sparc-sun-solaris2.8 --target=arm-none-symbianelf --prefix=/opt/codesourcery '--with-pkgversion=CodeSourcery ARM Sourcery G++ 2006q3-26' --with-bugurl=mailto:arm-gnu@codesourcery.com --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make -j4
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make install prefix=/scratch/paul/arm/install/host-sparc-sun-solaris2.8 htmldir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/man
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/install/host-sparc-sun-solaris2.8
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f lib/charset.alias
popd
copy_dir_clean /scratch/paul/arm/src/binutils-2.17/include /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/include
chmod -R u+w /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/include
mkdir -p /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/libiberty/libiberty.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bfd/.libs/libbfd.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/lib
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bfd/bfd.h /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/include
cp /scratch/paul/arm/src/binutils-2.17/bfd/elf-bfd.h /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/include
cp /scratch/paul/arm/obj/binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/opcodes/.libs/libopcodes.a /scratch/paul/arm/obj/host-binutils-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/usr/lib
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
rm -rf /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/gcc
cat > /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/as <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/arm-none-symbianelf/bin/as "$@"
EOF0
chmod +x /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/as
mkdir -p /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/gcc
cat > /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/collect-ld <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ld "$@"
EOF0
chmod +x /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/collect-ld
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
/scratch/paul/arm/src/gcc-2006q3/configure --build=i686-pc-linux-gnu --host=sparc-sun-solaris2.8 --target=arm-none-symbianelf --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery --enable-languages=c,c++ '--with-versuffix=CodeSourcery ARM Sourcery G++ 2006q3-26' '--with-pkgversion=CodeSourcery ARM Sourcery G++ 2006q3-26' --with-bugurl=mailto:arm-gnu@codesourcery.com --disable-nls
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make -j4 all-gcc
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/obj/gcc-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8
make prefix=/scratch/paul/arm/install/host-sparc-sun-solaris2.8 htmldir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/html pdfdir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/pdf infodir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/info mandir=/scratch/paul/arm/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q3-26-arm-none-symbianelf/man install-gcc
popd
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushenv
pushd /scratch/paul/arm/install/host-sparc-sun-solaris2.8
rm -f lib/libiberty.a
rm -f bin/arm-none-symbianelf-gccbug
rm -f lib/charset.alias
popd
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/lib/gcc/arm-none-symbianelf /scratch/paul/arm/install/host-sparc-sun-solaris2.8/lib/gcc/arm-none-symbianelf
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/arm-none-symbianelf/lib /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/lib
copy_dir /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/arm-none-symbianelf/include/c++ /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/include/c++
popenv
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushd /scratch/paul/arm/install/host-sparc-sun-solaris2.8
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f lib/charset.alias
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
find /scratch/paul/arm/install/host-sparc-sun-solaris2.8 -name '*.la' -exec rm '{}' ';'
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
pushd /scratch/paul/arm/install/host-sparc-sun-solaris2.8/lib/gcc/arm-none-symbianelf/4.1.1/include
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-addr2line
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-ar
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-as
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-c++
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-c++filt
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-cpp
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-g++
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gcc
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gcc-4.1.1
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gcov
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gprof
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-ld
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-nm
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-objcopy
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-objdump
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-ranlib
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-readelf
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-size
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-strings
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-strip
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ar
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/as
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/c++
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/g++
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/gcc
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ld
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/nm
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/objdump
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ranlib
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/strip
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/libexec/gcc/arm-none-symbianelf/4.1.1/cc1
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/libexec/gcc/arm-none-symbianelf/4.1.1/collect2
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/libexec/gcc/arm-none-symbianelf/4.1.1/install-tools/fixincl
sparc-sun-solaris2.8-strip /scratch/paul/arm/install/host-sparc-sun-solaris2.8/libexec/gcc/arm-none-symbianelf/4.1.1/cc1plus
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC sparc-sun-solaris2.8-gcc
prepend_path PATH /scratch/paul/arm/obj/tools-i686-pc-linux-gnu-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8/bin
rm -f /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8.tar.bz2
pushd /scratch/paul/arm/obj
rm -f arm-2006q3
ln -s /scratch/paul/arm/install/host-sparc-sun-solaris2.8 arm-2006q3
tar cjf /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf-sparc-sun-solaris2.8.tar.bz2 --owner=0 --group=0 arm-2006q3/arm-none-symbianelf arm-2006q3/bin arm-2006q3/include arm-2006q3/lib arm-2006q3/libexec arm-2006q3/share
rm -f arm-2006q3
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
cat > /scratch/paul/arm/obj/gnu-2006q3-26.txt <<'EOF0'
Version Information
===================

Version:           2006q3-26
Host(s):           i686-pc-linux-gnu i686-mingw32 sparc-sun-solaris2.8
Target:            arm-none-symbianelf

Build Information
=================

Build date:             20061101 00:13:11
Build machine:          sparrowhawk.codesourcery.com
Build operating system: Red Hat Enterprise Linux ES release 4 (Nahant Update 4)
Build uname:            Linux sparrowhawk.codesourcery.com 2.6.9-42.ELsmp #1 SMP Wed Jul 12 23:32:02 EDT 2006 x86_64 unknown unknown GNU/Linux
Build user:             paul

EOF0
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup
rm -rf /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts
mkdir /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-release /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-release
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-common /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-common
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-test
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-package /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-test-package
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-summary /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-test-summary
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-logconv-xfail /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-logconv-xfail
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-qemu /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-qemu
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-rpm-inst /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-rpm-inst
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/build-rpm-installer /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/build-rpm-installer
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-installanywhere /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-installanywhere
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-ia-helper /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-ia-helper
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/libia-common /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/libia-common
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/libia /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/libia
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/iap-sourcerygxx /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/iap-sourcerygxx
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-16x16-32bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-16x16-32bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-16x16-4bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-16x16-4bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-16x16-8bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-16x16-8bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-32x32-32bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-32x32-32bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-32x32-4bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-32x32-4bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-32x32-8bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-32x32-8bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-48x48-32bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-48x48-32bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-48x48-4bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-48x48-4bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-48x48-8bit.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-48x48-8bit.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-All_standard_formats.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-All_standard_formats.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl.ico /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl.ico
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-splash-green-455x295.png /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-splash-green-455x295.png
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-background-alt.jpg /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-background-alt.jpg
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources
cp /scratch/paul/arm/scripts/resources/csl-billboard.png /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/resources/csl-billboard.png
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/binutils /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/binutils
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/gcc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/gcc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/expat /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/expat
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/make /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/make
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/coreutils /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/coreutils
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/csl_docbook /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/csl_docbook
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/getting_started /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/getting_started
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/libiconv /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/libiconv
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/branding /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/branding
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/contents /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/contents
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules
cp /scratch/paul/arm/scripts/modules/comparison /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/modules/comparison
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./4.1-arm-none-symbianelf.cfg /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./4.1-arm-none-symbianelf.cfg
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./4.1-arm.inc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./4.1-arm.inc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./4.1-arm-sourceryg++.inc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./4.1-arm-sourceryg++.inc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./4.1-sourceryg++.inc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./4.1-sourceryg++.inc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./common.inc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./common.inc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./eclipse.inc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./eclipse.inc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./docs.inc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./docs.inc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/.
cp /scratch/paul/arm/scripts/release-configs/./4.1-arm-none-symbianelf.inc /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/release-configs/./4.1-arm-none-symbianelf.inc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-branding /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-test-branding
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-contents /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-test-contents
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-comparison /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-test-comparison
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/gnu-test-comparison-helper /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/gnu-test-comparison-helper
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/arm/scripts/objcompare.c /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf.backup/scripts/objcompare.c
pushd /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf
tar cjf /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf.backup.tar.bz2 --owner=0 --group=0 arm-2006q3-26-arm-none-symbianelf.backup
popd
popenv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
cp /scratch/paul/arm/obj/gnu-2006q3-26.txt /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
cp /scratch/paul/arm/logs/arm-2006q3-26-arm-none-symbianelf.sh /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf/arm-2006q3-26-arm-none-symbianelf
pushd /scratch/paul/arm/obj/pkg-2006q3-26-arm-none-symbianelf
tar cjf /scratch/paul/arm/pkg/arm-2006q3-26-arm-none-symbianelf.src.tar.bz2 --owner=0 --group=0 arm-2006q3-26-arm-none-symbianelf
popd
